<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location filename="../../Command.cpp" line="522"/>
      <source>File</source>
      <translation>Fitxer</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="523"/>
      <source>&amp;Export project...</source>
      <translation>&amp;Exportar projecte...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="524"/>
      <source>Export a Raytracing project to a file</source>
      <translation>Exportar un projecte de Raytracing a un arxiu</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewLuxProject</name>
    <message>
      <location filename="../../Command.cpp" line="756"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="757"/>
      <source>New Luxrender project</source>
      <translation>Nou projecte Luxrender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="758"/>
      <source>Insert new Luxrender project into the document</source>
      <translation>Inserir nou projecte Luxrender en el document</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="810"/>
      <source>No template</source>
      <translation>Cap plantilla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="811"/>
      <source>No template available</source>
      <translation>Cap plantilla disponible</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <location filename="../../Command.cpp" line="438"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="439"/>
      <source>Insert part</source>
      <translation>Inserir peça</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="440"/>
      <source>Insert a new part object into a Raytracing project</source>
      <translation>Inserir un nou objecte de part en un projecte de Raytracing</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <source>New POV-Ray project</source>
      <translation>Nou projecte de POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="323"/>
      <source>Insert new POV-Ray project into the document</source>
      <translation>Inserir el nou projecte de POV-Ray en el document</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>No template</source>
      <translation>Cap plantilla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="376"/>
      <source>No template available</source>
      <translation>Cap plantilla disponible</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingRender</name>
    <message>
      <location filename="../../Command.cpp" line="589"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="590"/>
      <source>&amp;Render</source>
      <translation>&amp;Render</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="591"/>
      <source>Renders the current raytracing project with an external renderer</source>
      <translation>Renderitza el projecte actual de traçat de raigs amb un renderitzador extern</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingResetCamera</name>
    <message>
      <location filename="../../Command.cpp" line="869"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="870"/>
      <source>&amp;Reset Camera</source>
      <translation>&amp;Reiniciar Càmera</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="871"/>
      <source>Sets the camera of the selected Raytracing project to match the current view</source>
      <translation>Estableix la posició de la càmera del projecte de traçat de raigs seleccionat perquè coincidisca amb la vista actual</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <location filename="../../Command.cpp" line="82"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Export camera to POV-Ray...</source>
      <translation>Exportar càmera a POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Export the camera position of the active 3D view in POV-Ray format to a file</source>
      <translation>Exporta la posició de la càmera de la vista 3D activa en format de POV-Ray a un fitxer</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Export part to POV-Ray...</source>
      <translation>Exportar peça a POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Write the selected Part (object) as a POV-Ray file</source>
      <translation>Escriviu la peça seleccionada (objecte) com a fitxer de POV-Ray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <location filename="../../Command.cpp" line="98"/>
      <location filename="../../Command.cpp" line="237"/>
      <location filename="../../Command.cpp" line="337"/>
      <location filename="../../Command.cpp" line="772"/>
      <source>No perspective camera</source>
      <translation>Cap càmera de Perspectiva</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="99"/>
      <location filename="../../Command.cpp" line="238"/>
      <location filename="../../Command.cpp" line="338"/>
      <source>The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
Do you want to continue?</source>
      <translation>La càmera de la vista actual no és en perspectiva i per tant el resultat de la imatge de POV-Ray podria ser diferent del que esperàveu.
Voleu continuar?</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Export view to POV-Ray...</source>
      <translation>Exportar vista a POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Write the active 3D view with camera and all its content to a POV-Ray file</source>
      <translation>Escriviu la vista 3D activa amb la càmera i tot el seu contingut en un fitxer POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="352"/>
      <location filename="../../Command.cpp" line="787"/>
      <source>No template</source>
      <translation>Cap plantilla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="353"/>
      <location filename="../../Command.cpp" line="788"/>
      <source>Cannot create a project because there is no template installed.</source>
      <translation>No es pot crear un projecte perquè no hi ha cap plantilla instal·lada.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="773"/>
      <source>The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
Do you want to continue?</source>
      <translation>La càmera de la vista actual no és en perspectiva i per tant el resultat de la imatge de LuxRender podria ser diferent del que esperàveu. 
Voleu continuar?</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="186"/>
      <location filename="../../Command.cpp" line="248"/>
      <location filename="../../Command.cpp" line="546"/>
      <source>POV-Ray</source>
      <translation>POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="136"/>
      <location filename="../../Command.cpp" line="187"/>
      <location filename="../../Command.cpp" line="249"/>
      <location filename="../../Command.cpp" line="551"/>
      <location filename="../../Command.cpp" line="665"/>
      <source>All Files</source>
      <translation>Tots els fitxers</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="137"/>
      <location filename="../../Command.cpp" line="188"/>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="553"/>
      <source>Export page</source>
      <translation>Exportar pàgina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="450"/>
      <location filename="../../Command.cpp" line="537"/>
      <location filename="../../Command.cpp" line="605"/>
      <location filename="../../Command.cpp" line="883"/>
      <source>Wrong selection</source>
      <translation>Selecció incorrecta</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="451"/>
      <source>Select a Part object.</source>
      <translation>Selecciona part del objecte.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="461"/>
      <location filename="../../Command.cpp" line="473"/>
      <source>No Raytracing project to insert</source>
      <translation>Cap projecte Raytracing per a inserir</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="462"/>
      <source>Create a Raytracing project to insert a view.</source>
      <translation>Creeu un projecte de traçat de raigs en què inserir una vista.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="474"/>
      <source>Select a Raytracing project to insert the view.</source>
      <translation>Seleccioneu un projecte de traçat de raigs en què inserir la vista.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="538"/>
      <location filename="../../Command.cpp" line="606"/>
      <location filename="../../Command.cpp" line="884"/>
      <source>Select one Raytracing project object.</source>
      <translation>Seleccioneu un objecte de projecte de Raytracing.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="542"/>
      <source>Luxrender</source>
      <translation>LuxRender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="621"/>
      <location filename="../../Command.cpp" line="627"/>
      <source>POV-Ray not found</source>
      <translation>POV-Ray no trobat</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="622"/>
      <source>Please set the path to the POV-Ray executable in the preferences.</source>
      <translation>Establiu el camí a l'executable del POV-Ray en les preferències.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="628"/>
      <source>Please correct the path to the POV-Ray executable in the preferences.</source>
      <translation>Corregiu el camí a l'executable del POV-Ray en les preferències.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="635"/>
      <location filename="../../Command.cpp" line="641"/>
      <source>Luxrender not found</source>
      <translation>No s'ha trobat el LuxRender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="636"/>
      <source>Please set the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>Establiu el camí a l'executable del LuxRender o Luxconsole en les preferències.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="642"/>
      <source>Please correct the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>Corregiu el camí a l'executable del LuxRender o Luxconsole en les preferències.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="654"/>
      <source>POV-Ray file missing</source>
      <translation>No es troba l'arxiu POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="655"/>
      <source>The POV-Ray project file doesn't exist.</source>
      <translation>No existeix el fitxer de projecte POV-Ray.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="661"/>
      <location filename="../../Command.cpp" line="663"/>
      <location filename="../../Command.cpp" line="666"/>
      <source>Rendered image</source>
      <translation>Imatge renderitzada</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="723"/>
      <source>Lux project file missing</source>
      <translation>Falta el fitxer del projecte Lux</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="724"/>
      <source>The Lux project file doesn't exist.</source>
      <translation>No existeix el fitxer de projecte Lux.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="14"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="26"/>
      <source>Mesh export settings</source>
      <translation>Ajustos d'exportació de malla</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="52"/>
      <source>Max mesh deviation:</source>
      <translation>Màxima desviació de malla:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="80"/>
      <source>Do not calculate vertex normals</source>
      <translation>No calcular les normals als vèrtexs</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="93"/>
      <source>Write u,v coordinates</source>
      <translation>Escriure coordenades u, v</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="109"/>
      <source>Render</source>
      <translation>Renderitzador</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="127"/>
      <source>POV-Ray executable:</source>
      <translation>Executable del POV-Ray:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="134"/>
      <source>POV-Ray output parameters:</source>
      <translation>Paràmetres d'eixida de POV-Ray:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="143"/>
      <source>The POV-Ray parameters to be passed to the render.</source>
      <translation>Els paràmetres de POV-Ray que es passen al renderitzador.</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="146"/>
      <source>+P +A</source>
      <translation>+P +A</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="159"/>
      <source>+W: </source>
      <translation>+W: </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="166"/>
      <source>The width of the rendered image</source>
      <translation>L'amplària de la imatge renderitzada</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="185"/>
      <source> +H : </source>
      <translation> +H: </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="192"/>
      <source>The height of the rendered image</source>
      <translation>L'alçària de la imatge renderitzada</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="213"/>
      <source>Luxrender executable:</source>
      <translation>Executable del LuxRender:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="220"/>
      <source>The path to the luxrender (or luxconsole) executable</source>
      <translation>El camí a l'executable del LuxRender (o Luxconsole)</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="238"/>
      <source>Directories</source>
      <translation>Directoris</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="258"/>
      <source>Part file name:</source>
      <translation>Nom del fitxer de peça:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="265"/>
      <source>Camera file name:</source>
      <translation>Nom del fitxer de la càmera:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="275"/>
      <location filename="../../DlgSettingsRay.ui" line="298"/>
      <location filename="../../DlgSettingsRay.ui" line="314"/>
      <source>Used by utility tools</source>
      <translation>Utilitzat per les eines d'utilitats</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="291"/>
      <source>Default Project dir:</source>
      <translation>Directori per defecte del projecte:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="301"/>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="317"/>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRayImp</name>
    <message>
      <location filename="../../DlgSettingsRayImp.cpp" line="47"/>
      <source>The path to the POV-Ray executable, if you want to render from %1</source>
      <translation>El camí a l'executable de POV-Ray, si voleu renderitzar des de %1</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderLux</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="68"/>
      <source>Edit LuxRender project</source>
      <translation>Editar el projecte LuxRender</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>LuxRender template</source>
      <translation>Plantilla LuxRender</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>Select a LuxRender template</source>
      <translation>Seleccionar una plantilla de LuxRender</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderPovray</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="147"/>
      <source>Edit Povray project</source>
      <translation>Editar el projecte Povray</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Povray template</source>
      <translation>Plantilla Povray</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Select a Povray template</source>
      <translation>Seleccionar una plantilla Povray</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>&amp;Raytracing</source>
      <translation>T&amp;raçat de raigs</translation>
    </message>
  </context>
</TS>
